@@ -57,8 +57,9 @@ CmodelValues <- setRefClass(
             return(varNames[!grepl('logProb_', varNames)])
         },
         expandNodeNames = function (nodeNames, returnType = "names", flatIndices = TRUE)  {
-            return(GID_map$expandNodeNames(nodeNames = nodeNames, returnType = returnType, 
-                                           flatIndices = flatIndices))
+            stop('There was a call to expandNodeNames for a compiled modelValues object.\n  This is deprecated and should not have occurred.\n  Please contact nimble developers at the nimble-users google group or at nimble.stats@gmail.com to let them know this happened.  \n Thank you.')
+##            return(GID_map$expandNodeNames(nodeNames = nodeNames, returnType = returnType, 
+##                                           flatIndices = flatIndices))
         },
         finalizeInternal = function() {
             finalize()
