@@ -185,7 +185,7 @@ getParam_keywordInfo <- keywordInfoClass(
 
         if(isCodeArgBlank(code, 'param'))
             stop("'param' argument missing from 'getParam', with no accessor argument supplied")
-        paramInfo_ArgList <- list(model = code$model, node = nodeFunVec_ArgList$nodes, param = code$param) ## use nodeFunVec_ArgList$nodes instead of code$node because nodeFunVec_ArgList$nodes may have been updated if code$nodes has a run-time index.  In that case the paramID will be vector
+        paramInfo_ArgList <- list(model = code$model, node = nodeFunVec_ArgList$nodes, param = code$param, hasIndex = useNodeFunctionVectorByIndex) ## use nodeFunVec_ArgList$nodes instead of code$node because nodeFunVec_ArgList$nodes may have been updated if code$nodes has a run-time index.  In that case the paramID will be vector
         paramInfoName <- paramInfo_SetupTemplate$makeName(paramInfo_ArgList)
         paramIDname <- paramInfo_SetupTemplate$makeOtherNames(paramInfoName, paramInfo_ArgList)
 
@@ -1069,7 +1069,7 @@ paramInfo_SetupTemplate <- setupCodeTemplateClass(
     makeName = function(argList){Rname2CppName(paste(deparse(argList$model), deparse(argList$node), deparse(argList$param), 'paramInfo', sep='_'))},
     makeOtherNames = function(name,argList) {Rname2CppName(paste0(name,'_ID'))},
     codeTemplate = quote({
-        PARAMINFONAME <- nimble:::makeParamInfo(MODEL, NODE, PARAM)
+        PARAMINFONAME <- nimble:::makeParamInfo(model = MODEL, nodes = NODE, param = PARAM, vector = HASINDEX )
         PARAMIDNAME <- PARAMINFONAME$paramID
         PARAMINFONAME$paramID <- NULL
        }),
@@ -1078,7 +1078,8 @@ paramInfo_SetupTemplate <- setupCodeTemplateClass(
              PARAMIDNAME = as.name(paste0(resultName,'_ID')),
              MODEL = argList$model,
              NODE = argList$node,
-             PARAM = argList$param)
+             PARAM = argList$param,
+             HASINDEX = argList$hasIndex)
     })
 
 boundInfo_SetupTemplate <- setupCodeTemplateClass(
