@@ -280,11 +280,11 @@ test_that("dgamma-dinvgamma conjugacy with dependency using rate", {
 
 # dinvwish_chol
 
-test_that("Test that rinvwish_chol, dinvwish_chol, and rwish_chol give correct results", {
+test_that("Test that rinvwish_chol, dinvwish_chol, dwish_chol, and rwish_chol give correct results", {
     set.seed(1)
-    df <- 20
-    d <- 3
-    C <- crossprod(matrix(rnorm(d^2, 3), d))
+    df <- 20.3
+    d <- 5
+    C <- crossprod(matrix(rnorm(d^2, 0), d))
     pm <- C / (df - d - 1)
     
     n <- 100
@@ -303,15 +303,16 @@ test_that("Test that rinvwish_chol, dinvwish_chol, and rwish_chol give correct r
     for(i in 1:n)
         draws3[,,i] <- rinvwish_chol(1, chol(solve(C)), df, scale_param = FALSE)
     pmean3 <- apply(draws3, c(1,2), mean)
-    expect_equal(max(abs(pmean1 - pm)), 0, tol = 0.06,
+    expect_equal(max(abs(pmean1 - pm)), 0, tol = 0.03,
                  info = "mean of inverse of rwish draws differs from truth")
-    expect_equal(max(abs(pmean2 - pm)), 0, tol = 0.06,
+    expect_equal(max(abs(pmean2 - pm)), 0, tol = 0.03,
                  info = "mean of rinvwish with scale draws differs from truth")
-    expect_equal(max(abs(pmean3 - pm)), 0, tol = 0.06,
+    expect_equal(max(abs(pmean3 - pm)), 0, tol = 0.03,
                  info = "mean of rinvwish with rate differs from truth")
 
-    dens1 <- dinvwish_chol(draws1[,,1], chol(C), df, log = TRUE)
-    dens2 <- dinvwish_chol(draws1[,,1], chol(solve(C)), df, log = TRUE, scale_param = FALSE)
+    # draws1 is from rwish not rinvwish, but for comparing density values it doesn't matter their origin.
+    dens1 <- dinvwish_chol(draws1[,,1], chol(C), df, scale_param = TRUE, log = TRUE)
+    dens2 <- dinvwish_chol(draws1[,,1], chol(solve(C)), df, scale_param = FALSE, log = TRUE)
     
     dfun <- function(W, S, nu) {
         k <- nrow(W)
@@ -325,6 +326,23 @@ test_that("Test that rinvwish_chol, dinvwish_chol, and rwish_chol give correct r
                  info = "dinvwish with scale differs from truth")
     expect_equal(dens2-dens3, 0, tol = 0.000001,
                  info = "dinvwish with rate differs from truth")
+
+    dens1 <- dwish_chol(draws1[,,1], chol(C), df, scale_param = TRUE, log = TRUE)
+    dens2 <- dwish_chol(draws1[,,1], chol(solve(C)), df, scale_param = FALSE, log = TRUE)
+
+    dfun <- function(W, S, nu) {
+        k <- nrow(W)
+        U = chol(S)
+        return(-(log(2)*nu*k/2+(k*(k-1)/4)*log(pi) +sum(lgamma((nu + 1 - 1:k)/2))) - nu*sum(log(diag(U))) +
+               (nu-k-1)*sum(log(diag(chol(W)))) -0.5*sum(diag(solve(S, W))))               
+    }
+
+    dens3 <-  dfun(draws1[,,1], C, df)
+    expect_equal(dens1-dens3, 0, tol = 0.000001,
+                 info = "dinvwish with scale differs from truth")
+    expect_equal(dens2-dens3, 0, tol = 0.000001,
+                 info = "dinvwish with rate differs from truth")
+
 })
                                                                         
 set.seed(1)
